@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -43,8 +39,13 @@ static char sccsid[] = "@(#)cmds.c	8.6 (Berkeley) 10/9/94";
 #endif
 
 #include <sys/param.h>
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <fcntl.h>
+
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/ftp.h>
@@ -611,7 +612,13 @@ mput(argc, argv)
 		}
 
 		memset(&gl, 0, sizeof(gl));
-		flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_TILDE;
+		flags = GLOB_NOCHECK;
+#ifdef GLOB_BRACE
+		flags |= GLOB_BRACE;
+#endif
+#ifdef GLOB_TILDE
+		flags |= GLOB_TILDE;
+#endif
 #ifdef GLOB_QUOTE
 		flags |= GLOB_QUOTE;
 #endif
@@ -741,11 +748,11 @@ usage:
 					    &yy, &mo, &day, &hour, &min, &sec);
 					tm = gmtime(&stbuf.st_mtime);
 					tm->tm_mon++;
-					if (tm->tm_year > yy%100) {
+					if (tm->tm_year + 1900 > yy) {
 						free (local);
 						return (1);
 					}
-					if ((tm->tm_year == yy%100 &&
+					if ((tm->tm_year + 1900 == yy &&
 					    tm->tm_mon > mo) ||
 					   (tm->tm_mon == mo &&
 					    tm->tm_mday > day) ||
@@ -868,6 +875,7 @@ remglob(argv,doswitch)
 	char *buf = 0;
 	int sofar = 0;
 	int oldverbose, oldhash;
+	int fd;
 	char *cp, *mode, *end;
 
 	if (!mflag) {
@@ -894,7 +902,20 @@ remglob(argv,doswitch)
 
 		strcpy (temp, PATH_TMP);
 		strcat (temp, "XXXXXX");
-		mktemp (temp);
+#ifdef HAVE_MKSTEMP
+		fd = mkstemp (temp);
+#else
+		if (mktemp (temp) != NULL)
+			fd = open(temp, O_CREAT|O_EXCL|O_RDWR, 0600);
+		else
+			fd = -1;
+#endif
+		if (fd < 0) {
+		  printf("unable to create temporary file %s: %s\n", temp,
+			 strerror(errno));
+		  return (NULL);
+		}
+		close (fd);
 
 		oldverbose = verbose, verbose = 0;
 		oldhash = hash, hash = 0;
@@ -1045,12 +1066,15 @@ sethash(argc, argv)
 	int argc;
 	char *argv[];
 {
-
+	if (argv[1] != NULL)
+		sscanf(argv[1], "%d", &hashbytes);
+	if (hashbytes <= 0)
+		hashbytes=1024;
 	hash = !hash;
 	printf("Hash mark printing %s", onoff(hash));
 	code = hash;
 	if (hash)
-		printf(" (%d bytes/hash mark)", 1024);
+		printf(" (%d bytes/hash mark)", hashbytes);
 	printf(".\n");
 }
 
@@ -1178,6 +1202,7 @@ lcd(argc, argv)
 	char *argv[];
 {
 	char *dir;
+	extern char *xgetcwd();
 
 	if (argc < 2)
 		argc++, argv[1] = home;
@@ -1202,21 +1227,7 @@ lcd(argc, argv)
 
 	free (dir);
 
-#ifdef HAVE_GETCWD_ZERO_SIZE
-	/* A size arg of zero means `as big as necessary.  */
-	dir = getcwd (0, 0);
-#else /* !HAVE_GETCWD_ZERO_SIZE */
-#ifdef PATH_MAX
-	dir = getcwd (0, PATH_MAX);
-#else /* !PATH_MAX */
-#ifdef MAXPATHLEN
-	dir = getcwd (0, MAXPATHLEN);
-#else /* !MAXPATHLEN */
-	dir = getcwd (0, 2048);
-#endif /* MAXPATHLEN */
-#endif /* PATH_MAX */
-#endif /* HAVE_GETCWD_ZERO_SIZE */
-
+	dir = xgetcwd ();
 	if (dir) {
 		printf("Local directory now %s\n", dir);
 		free (dir);
@@ -1803,12 +1814,13 @@ account(argc,argv)
 	if (argc > 1) {
 		++argv;
 		--argc;
-		(void) strncpy(acct,*argv,49);
-		acct[49] = '\0';
+		(void) strncpy(acct,*argv, sizeof(acct) - 1);
+		acct[sizeof(acct) - 1] = '\0';
 		while (argc > 1) {
 			--argc;
 			++argv;
-			(void) strncat(acct,*argv, 49-strlen(acct));
+			(void) strncat(acct,*argv,
+				(sizeof(acct) - 1) - strlen(acct));
 		}
 		ap = acct;
 	}
@@ -1930,14 +1942,14 @@ setntrans(argc,argv)
 	}
 	ntflag++;
 	code = ntflag;
-	(void) strncpy(ntin, argv[1], 16);
-	ntin[16] = '\0';
+	(void) strncpy(ntin, argv[1], sizeof(ntin) - 1);
+	ntin[sizeof(ntin) - 1] = '\0';
 	if (argc == 2) {
 		ntout[0] = '\0';
 		return;
 	}
-	(void) strncpy(ntout, argv[2], 16);
-	ntout[16] = '\0';
+	(void) strncpy(ntout, argv[2], sizeof(ntout) - 1);
+	ntout[sizeof(ntout) - 1] = '\0';
 }
 
 char *
@@ -1948,11 +1960,11 @@ dotrans(name)
 	char *cp1, *cp2 = new;
 	int i, ostop, found;
 
-	for (ostop = 0; *(ntout + ostop) && ostop < 16; ostop++)
+	for (ostop = 0; *(ntout + ostop) && ostop < sizeof(ntout) - 1; ostop++)
 		continue;
 	for (cp1 = name; *cp1; cp1++) {
 		found = 0;
-		for (i = 0; *(ntin + i) && i < 16; i++) {
+		for (i = 0; *(ntin + i) && i < sizeof(ntin) - 1; i++) {
 			if (*cp1 == *(ntin + i)) {
 				found++;
 				if (i < ostop) {
@@ -2217,7 +2229,7 @@ setrunique(argc, argv)
 	code = runique;
 }
 
-/* change directory to perent directory */
+/* change directory to parent directory */
 void
 cdup(argc, argv)
 	int argc;
@@ -2368,7 +2380,7 @@ modtime(argc, argv)
 }
 
 /*
- * show status on reomte machine
+ * show status on remote machine
  */
 void
 rmtstatus(argc, argv)
