@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -88,12 +84,12 @@ static char sccsid[] = "@(#)ftp.c	8.6 (Berkeley) 10/27/94";
 
 #include "ftp_var.h"
 
-#ifndef HAVE_FCLOSE_DECL
+#if !HAVE_DECL_FCLOSE
 /* Some systems don't declare fclose in <stdio.h>, so do it ourselves.  */
 extern int fclose __P ((FILE *));
 #endif
 
-#ifndef HAVE_PCLOSE_DECL
+#if !HAVE_DECL_PCLOSE
 /* Some systems don't declare pclose in <stdio.h>, so do it ourselves.  */
 extern int pclose __P ((FILE *));
 #endif
@@ -144,7 +140,12 @@ hookup(host, port)
 		}
 		hisctladdr.sin_family = hp->h_addrtype;
 		memmove((caddr_t)&hisctladdr.sin_addr,
-				hp->h_addr_list[0], hp->h_length);
+#ifdef HAVE_STRUCT_HOSTENT_H_ADDR_LIST
+				hp->h_addr_list[0],
+#else
+				hp->h_addr,
+#endif
+				hp->h_length);
 		(void) strncpy(hostnamebuf, hp->h_name, sizeof(hostnamebuf));
 	}
 	hostname = hostnamebuf;
@@ -156,6 +157,7 @@ hookup(host, port)
 	}
 	hisctladdr.sin_port = port;
 	while (connect(s, (struct sockaddr *)&hisctladdr, sizeof (hisctladdr)) < 0) {
+#ifdef HAVE_STRUCT_HOSTENT_H_ADDR_LIST
 		if (hp && hp->h_addr_list[1]) {
 			int oerrno = errno;
 			char *ia;
@@ -177,6 +179,7 @@ hookup(host, port)
 			}
 			continue;
 		}
+#endif
 		warn("connect");
 		code = -1;
 		goto bad;
@@ -193,7 +196,9 @@ hookup(host, port)
 		warn("setsockopt TOS (ignored)");
 #endif
 	cin = fdopen(s, "r");
-	cout = fdopen(s, "w");
+	/* dup(s) is for sake of stdio implementations who do not
+		allow two fdopen's on the same file-descriptor */
+	cout = fdopen(dup(s), "w");
 	if (cin == NULL || cout == NULL) {
 		warnx("fdopen failed.");
 		if (cin)
@@ -287,6 +292,13 @@ login(host)
 		return (1);
 	for (n = 0; n < macnum; ++n) {
 		if (!strcmp("init", macros[n].mac_name)) {
+#if HAVE_LIBREADLINE
+			if (line)
+				free (line);
+			line = calloc (200, sizeof (*line));
+			if (!line)
+				quit (0, 0);
+#endif
 			(void) strcpy(line, "$init");
 			makeargv();
 			domacro(margc, margv);
@@ -335,7 +347,7 @@ va_dcl
 #endif
 		if (strncmp("PASS ", fmt, 5) == 0)
 			printf("PASS XXXX");
-		else 
+		else
 			vfprintf(stdout, fmt, ap);
 		va_end(ap);
 		printf("\n");
@@ -495,8 +507,6 @@ abortsend(sig)
 	longjmp(sendabort, 1);
 }
 
-#define HASHBYTES 1024
-
 void
 sendrequest(cmd, local, remote, printnames)
 	char *cmd, *local, *remote;
@@ -508,7 +518,7 @@ sendrequest(cmd, local, remote, printnames)
 	FILE *fin, *dout = 0, *popen();
 	int (*closefunc) __P((FILE *));
 	sig_t oldintr, oldintp;
-	long bytes = 0, hashbytes = HASHBYTES;
+	long bytes = 0, local_hashbytes=hashbytes;
 	char *lmode, buf[BUFSIZ], *bufp;
 
 	if (verbose && printnames) {
@@ -650,15 +660,15 @@ sendrequest(cmd, local, remote, printnames)
 				if ((d = write(fileno(dout), bufp, c)) <= 0)
 					break;
 			if (hash) {
-				while (bytes >= hashbytes) {
+				while (bytes >= local_hashbytes) {
 					(void) putchar('#');
-					hashbytes += HASHBYTES;
+					local_hashbytes += hashbytes;
 				}
 				(void) fflush(stdout);
 			}
 		}
 		if (hash && bytes > 0) {
-			if (bytes < HASHBYTES)
+			if (bytes < local_hashbytes)
 				(void) putchar('#');
 			(void) putchar('\n');
 			(void) fflush(stdout);
@@ -666,7 +676,7 @@ sendrequest(cmd, local, remote, printnames)
 		if (c < 0)
 			warn("local: %s", local);
 		if (d < 0) {
-			if (errno != EPIPE) 
+			if (errno != EPIPE)
 				warn("netout");
 			bytes = -1;
 		}
@@ -675,10 +685,10 @@ sendrequest(cmd, local, remote, printnames)
 	case TYPE_A:
 		while ((c = getc(fin)) != EOF) {
 			if (c == '\n') {
-				while (hash && (bytes >= hashbytes)) {
+				while (hash && (bytes >= local_hashbytes)) {
 					(void) putchar('#');
 					(void) fflush(stdout);
-					hashbytes += HASHBYTES;
+					local_hashbytes += hashbytes;
 				}
 				if (ferror(dout))
 					break;
@@ -690,10 +700,10 @@ sendrequest(cmd, local, remote, printnames)
 	/*		if (c == '\r') {			  	*/
 	/*		(void)	putc('\0', dout);  // this violates rfc */
 	/*			bytes++;				*/
-	/*		}                          			*/	
+	/*		}                          			*/
 		}
 		if (hash) {
-			if (bytes < hashbytes)
+			if (bytes < local_hashbytes)
 				(void) putchar('#');
 			(void) putchar('\n');
 			(void) fflush(stdout);
@@ -766,7 +776,7 @@ recvrequest(cmd, local, remote, lmode, printnames)
 	int c, d, is_retr, tcrflag, bare_lfs = 0, blksize;
 	static int bufsize=0;
 	static char *buf;
-	long bytes = 0, hashbytes = HASHBYTES;
+	long bytes = 0, local_hashbytes = hashbytes;
 	struct timeval start, stop;
 	struct stat st;
 
@@ -886,15 +896,15 @@ recvrequest(cmd, local, remote, lmode, printnames)
 				break;
 			bytes += c;
 			if (hash) {
-				while (bytes >= hashbytes) {
+				while (bytes >= local_hashbytes) {
 					(void) putchar('#');
-					hashbytes += HASHBYTES;
+					local_hashbytes += hashbytes;
 				}
 				(void) fflush(stdout);
 			}
 		}
 		if (hash && bytes > 0) {
-			if (bytes < HASHBYTES)
+			if (bytes < local_hashbytes)
 				(void) putchar('#');
 			(void) putchar('\n');
 			(void) fflush(stdout);
@@ -937,10 +947,10 @@ done:
 			if (c == '\n')
 				bare_lfs++;
 			while (c == '\r') {
-				while (hash && (bytes >= hashbytes)) {
+				while (hash && (bytes >= local_hashbytes)) {
 					(void) putchar('#');
 					(void) fflush(stdout);
-					hashbytes += HASHBYTES;
+					local_hashbytes += hashbytes;
 				}
 				bytes++;
 				if ((c = getc(din)) != '\n' || tcrflag) {
@@ -965,7 +975,7 @@ break2:
 			printf("File may not have transferred correctly.\n");
 		}
 		if (hash) {
-			if (bytes < hashbytes)
+			if (bytes < local_hashbytes)
 				(void) putchar('#');
 			(void) putchar('\n');
 			(void) fflush(stdout);
@@ -1088,7 +1098,7 @@ initconn()
 noport:
 	data_addr = myctladdr;
 	if (sendport)
-		data_addr.sin_port = 0;	/* let system pick one */ 
+		data_addr.sin_port = 0;	/* let system pick one */
 	if (data != -1)
 		(void) close(data);
 	data = socket(AF_INET, SOCK_STREAM, 0);
@@ -1298,10 +1308,10 @@ pswitch(flag)
 	mcase = op->mcse;
 	ip->ntflg = ntflag;
 	ntflag = op->ntflg;
-	(void) strncpy(ip->nti, ntin, 16);
+	(void) strncpy(ip->nti, ntin, sizeof(ntin) - 1);
 	(ip->nti)[strlen(ip->nti)] = '\0';
 	(void) strcpy(ntin, op->nti);
-	(void) strncpy(ip->nto, ntout, 16);
+	(void) strncpy(ip->nto, ntout, sizeof(ntout) - 1);
 	(ip->nto)[strlen(ip->nto)] = '\0';
 	(void) strcpy(ntout, op->nto);
 	ip->mapflg = mapflag;
@@ -1550,7 +1560,7 @@ abort_remote(din)
 	(void) fflush(cout);
 	FD_ZERO(&mask);
 	FD_SET(fileno(cin), &mask);
-	if (din) { 
+	if (din) {
 		FD_SET(fileno(din), &mask);
 	}
 	if ((nfnd = empty(&mask, 10)) <= 0) {
