@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -48,11 +44,9 @@ static char sccsid[] = "@(#)genget.c	8.2 (Berkeley) 5/30/95";
  * the length is returned.  If *s1 is a prefix of *s2,
  * the length of *s1 is returned.
  */
-	int
-isprefix(s1, s2)
-	register char *s1, *s2;
+int
+isprefix(register char *s1, register char *s2)
 {
-        register int n = 0;
         char *os1;
 	register char c1, c2;
 
@@ -72,11 +66,10 @@ isprefix(s1, s2)
 
 static char *ambiguous;		/* special return value for command routines */
 
-	char **
-genget(name, table, stlen)
-	char	*name;		/* name to match */
-	char	**table;	/* name entry in table */
-	int	stlen;
+/* char	*name; name to match */
+/* char	**table; name entry in table */
+char **
+genget(char	*name, char	**table, int	stlen)
 {
 	register char **c, **found;
 	register int n;
@@ -100,9 +93,8 @@ genget(name, table, stlen)
 /*
  * Function call version of Ambiguous()
  */
-	int
-Ambiguous(s)
-	char *s;
+int
+Ambiguous(char *s)
 {
 	return((char **)s == &ambiguous);
 }
