@@ -101,6 +101,26 @@ static void decode_type (const char *optarg);
 static void init_data_buffer (u_char *pat, int len);
 static int send_echo (PING *ping);
 
+static size_t
+ping_cvt_number (const char *optarg, size_t maxval)
+{
+  char *p;
+  size_t n;
+
+  n = strtoul (optarg, &p, 0);
+  if (*p)
+    {
+      fprintf (stderr, "Invalid value (`%s' near `%s')\n", optarg, p);
+      exit (1);
+    }
+  if (maxval && n > maxval)
+    {
+      fprintf (stderr, "Option value too big: %s\n", optarg);
+      exit (1);
+    }
+  return n;
+}
+
 int
 main (int argc, char **argv)
 {
@@ -138,45 +158,58 @@ main (int argc, char **argv)
 	  printf ("see the files named COPYING.\n");
 	  exit (0);
 	  break;
+	  
 	case 'L':
 	  show_license ();
 	  exit (0);
+	  
 	case 'h':
 	  show_usage ();
 	  exit (0);
 	  break;
+	  
 	case 'c':
-	  ping_set_count (ping, atoi (optarg));
+	  ping_set_count (ping, ping_cvt_number (optarg, 0));
 	  break;
+	  
 	case 'd':
 	  ping_set_sockopt (ping, SO_DEBUG, &one, sizeof (one));
 	  break;
+	  
 	case 'r':
 	  ping_set_sockopt (ping, SO_DONTROUTE, &one, sizeof (one));
 	  break;
+	  
 	case 'i':
 	  options |= OPT_INTERVAL;
-	  ping_set_interval (ping, atoi (optarg));
+	  ping_set_interval (ping, ping_cvt_number (optarg, 0));
 	  break;
+	  
 	case 'p':
 	  decode_pattern (optarg, &pattern_len, pattern);
 	  patptr = pattern;
 	  break;
+	  
  	case 's':
-	  data_length = atoi (optarg);
+	  data_length = ping_cvt_number (optarg, PING_MAX_DATALEN);
  	  break;
+	  
 	case 'n':
 	  options |= OPT_NUMERIC;
 	  break;
+	  
 	case 'q':
 	  options |= OPT_QUIET;
 	  break;
+	  
 	case 'R':
 	  options |= OPT_RROUTE;
 	  break;
+	  
         case 'v':
 	  options |= OPT_VERBOSE;
 	  break;
+	  
 	case 'l':
 	  if (!is_root)
 	    {
@@ -208,12 +241,15 @@ main (int argc, char **argv)
 	case ICMP_ECHO:
 	  decode_type ("echo");
 	  break;
+	  
 	case ICMP_TIMESTAMP:
 	  decode_type ("timestamp");
 	  break;
+	  
 	case ICMP_ADDRESS:
 	  decode_type ("address");
 	  break;
+	  
 	case ICMP_ROUTERDISCOVERY:
 	  decode_type ("router");
 	  break;
@@ -234,17 +270,6 @@ main (int argc, char **argv)
 
   init_data_buffer (patptr, pattern_len);
 
-  ping = ping_init (ICMP_ECHO, getpid ());
-  if (ping == NULL)
-    {
-      fprintf (stderr, "can't init ping: %s\n", strerror (errno));
-      exit (1);
-    }
-  ping_set_sockopt (ping, SO_BROADCAST, (char *)&one, sizeof (one));
-  
-  /* Reset root privileges */
-  setuid (getuid ());
-  
   return (*ping_type)(argc, argv);
 }
 
@@ -333,7 +358,8 @@ ping_run (PING *ping, int (*finish)())
   struct timeval last, intvl, now;
   struct timeval *t = NULL;
   int finishing = 0;
-  
+  int nresp = 0;
+
   signal (SIGINT, sig_int);
   
   fdmax = ping->ping_fd+1;
@@ -382,23 +408,24 @@ ping_run (PING *ping, int (*finish)())
       if ((n = select (fdmax, &fdset, NULL, NULL, &timeout)) < 0)
 	{
 	  if (errno != EINTR)
-	    perror ("ping: select");
+	    perror ("select");
 	  continue;
 	}
       else if (n == 1)
 	{
-	  len = ping_recv (ping);
+	  if (ping_recv (ping) == 0)
+	    nresp++;
 	  if (t == 0)
 	    {
 	      gettimeofday (&now, NULL);
 	      t = &now;
 	    }
-	  if (ping->ping_count && ping->ping_num_recv >= ping->ping_count)
+	  if (ping->ping_count && nresp >= ping->ping_count)
 	    break;
 	}
       else
 	{
-	  if (!ping->ping_count || ping->ping_num_recv < ping->ping_count)
+	  if (!ping->ping_count || ping->ping_num_xmit < ping->ping_count)
 	    {
 	      send_echo (ping);
 	      if (!(options & OPT_QUIET) && options & OPT_FLOOD)
@@ -409,7 +436,7 @@ ping_run (PING *ping, int (*finish)())
 	  else if (finishing)
 	    break;
 	  else
-	    {
+ 	    {
 	      finishing = 1;
 
 	      intvl.tv_sec = MAXWAIT;
@@ -436,8 +463,8 @@ send_echo (PING *ping)
     }
   if (data_buffer)
     ping_set_data (ping, data_buffer, off,
-		  data_length > PING_HEADER_LEN ?
-		    data_length-PING_HEADER_LEN : data_length);
+		   data_length > PING_HEADER_LEN ?
+		   data_length - PING_HEADER_LEN : data_length);
   return ping_xmit (ping);
 }
 
