@@ -557,6 +557,9 @@ main (int argc, char *argv[])
       exit (2);
     }
 
+  /* read configuration file */
+  init (0);
+
 #ifdef PATH_KLOG
   /* Initialize kernel logging and add to the list.  */
   if (!NoKLog)
@@ -608,9 +611,6 @@ main (int argc, char *argv[])
 	dbg_printf ("Can't open UDP port: %s\n", strerror (errno));
     }
 
-  /* read configuration file */
-  init (0);
-
   /* Tuck my process id away.  */
   fp = fopen (PidFile, "w");
   if (fp != NULL)
@@ -668,59 +668,25 @@ main (int argc, char *argv[])
 		continue;
 	    else if (fdarray[i].fd == fklog)
 	      {
-		/* Set to 1 if the kline possibly contains a log message.  */
-		int log_kline = 0;
+		result = read (fdarray[i].fd, &kline[kline_len],
+			       sizeof (kline) - kline_len - 1);
 
-		/*dbg_printf ("klog message\n");*/
-
-		if (kline_len == sizeof (kline) - 1)
+		if (result > 0)
 		  {
-		    /* We are trying to find the end of an earlier
-		       logged partial line.  */
-
-		    result = read (fdarray[i].fd, kline, sizeof (kline) - 1);
-		    if (result > 0)
-		      {
-			char *eol;
-
-			kline[result] = '\0';
-			eol = strchr (kline, '\n');
-			if (eol)
-			  {
-			    eol++;
-			    kline_len = result - (eol - kline);
-			    memmove (kline, eol, kline_len);
-			    log_kline = 1;
-			  }
-		      }
-		    else if (result < 0 && errno != EINTR)
-		      {
-			logerror ("klog");
-			fdarray[i].fd = fklog = -1;
-		      }
+		    kline_len += result;
 		  }
-		else
+		else if (result < 0 && errno != EINTR)
 		  {
-		    result = read (fdarray[i].fd, &kline[kline_len],
-				   sizeof (kline) - kline_len - 1);
-
-		    if (result > 0)
-		      {
-			kline_len += result;
-			log_kline = 1;
-		      }
-		    else if (result < 0 && errno != EINTR)
-		      {
-			logerror ("klog");
-			fdarray[i].fd = fklog = -1;
-		      }
+		    logerror ("klog");
+		    fdarray[i].fd = fklog = -1;
 		  }
 
-		if (log_kline)
+		while (1)
 		  {
 		    char *bol, *eol;
-		    
+
 		    kline[kline_len] = '\0';
+
 		    for (bol = kline, eol = strchr (kline, '\n'); eol;
 			 bol = eol, eol = strchr (bol, '\n'))
 		      {
@@ -728,9 +694,54 @@ main (int argc, char *argv[])
 			kline_len -= (eol - bol);
 			printsys (bol);
 		      }
-		    if (*bol)
-		      /* Log the beginning of a partial line.  */
-		      printsys (bol);
+
+		    /* This loop makes sure the daemon won't lock up
+		     * on null bytes in the klog stream.  They still hurt 
+		     * efficiency, acting like a message separator that 
+		     * forces a shift-and-reiterate when the buffer was
+		     * never full.
+		     */
+		    while (kline_len && !*bol)
+		      {
+			bol++;
+			kline_len--;
+		      }
+
+		    if (!kline_len)
+		      break;
+
+		    if (bol != kline)
+		      {
+			/* shift the partial line to start of buffer, so 
+			 * we can re-iterate.
+			 */
+			memmove (kline, bol, kline_len);
+		      }
+		    else
+		      {
+			if (kline_len < MAXLINE)
+			  break;
+
+			/* The pathological case of a single message that
+			 * overfills our buffer.  The best we can do is
+			 * log it in pieces.
+			 */
+			printsys (kline);
+
+			/* Clone priority signal if present 
+			 * We merely shift the kline_len pointer after
+			 * it so the next chunk is written after it.
+			 *
+			 * strchr(kline,'>') is not used as it would allow 
+			 * a pathological line ending in '>' to cause an
+			 * endless loop.
+			 */
+			if (kline[0] == '<'
+			    && isdigit (kline[1]) && kline[2] == '>')
+			  kline_len = 3;
+			else
+			  kline_len = 0;
+		      }
 		  }
 	      }
 	    else if (fdarray[i].fd == finet)
@@ -1108,8 +1119,7 @@ logmsg (int pri, const char *msg, const char *from, int flags)
   for (f = Files; f; f = f->f_next)
     {
       /* Skip messages that are incorrect priority. */
-      if (!(f->f_pmask[fac] & LOG_MASK (prilev)) ||
-	  f->f_pmask[fac] == INTERNAL_NOPRI)
+      if (!(f->f_pmask[fac] & LOG_MASK (prilev)))
 	continue;
 
       if (f->f_type == F_CONSOLE && (flags & IGN_CONS))
@@ -1610,6 +1620,7 @@ init (int signo)
   size_t line_max = LINE_MAX;
   char *cbuf;
   char *cline;
+  int cont_line = 0;
   struct servent *sp;
 
   (void) signo;  /* Ignored.  */
@@ -1669,7 +1680,7 @@ init (int signo)
   cbuf = malloc (line_max);
   if (cbuf == NULL)
     {
-      /* There is no gracefull recovery here.  */
+      /* There is no graceful recovery here.  */
       dbg_printf ("cannot allocate space for configuration\n");
       return;
     }
@@ -1686,9 +1697,24 @@ init (int signo)
     {
       size_t len = strlen (cline);
 
-      /* No newline ? then line is too big for the buffer readjust.  */
-      if (memchr (cline, '\n', len) == NULL)
+      /* If this is a continuation line, skip leading whitespace for
+	 compatibility with sysklogd.  Note that this requires
+	 whitespace before the backslash in the previous line if you
+	 want to separate the selector from the action.  */
+      if (cont_line)
 	{
+	  char *start = cline;
+	  while (*start == ' ' || *start == '\t')
+	    start++;
+	  len = len - (start - cline);
+	  memmove (cline, start, len + 1);
+	  cont_line = 0;
+	}
+
+      /* No newline, so the line is too big for the buffer.  Readjust.  */
+      if (strchr (cline, '\n') == NULL)
+	{
+	  size_t offset = cline - cbuf;
 	  char *tmp;
 	  tmp = realloc (cbuf, line_max * 2);
 	  if (tmp == NULL)
@@ -1701,8 +1727,7 @@ init (int signo)
 	  else
 	    cbuf = tmp;
 	  line_max *= 2;
-	  strcpy (cbuf, cline);
-	  cline += len;
+	  cline = cbuf + offset + len - 1;
 	  continue;
 	}
       else
@@ -1727,6 +1752,7 @@ init (int signo)
 	{
 	  *p = '\0';
 	  cline = p;
+	  cont_line = 1;
 	  continue;
 	}
 
@@ -1751,7 +1777,7 @@ init (int signo)
 	{
 	  int i;
 	  for (i = 0; i <= LOG_NFACILITIES; i++)
-	    if (f->f_pmask[i] == INTERNAL_NOPRI)
+	    if (f->f_pmask[i] == 0)
 	      dbg_printf(" X ");
 	    else
 	      dbg_printf("%2x ", f->f_pmask[i]);
@@ -1809,7 +1835,7 @@ cfline (const char *line, struct filed *f)
   memset (f, 0, sizeof (*f));
   for (i = 0; i <= LOG_NFACILITIES; i++)
     {
-      f->f_pmask[i] = INTERNAL_NOPRI;
+      f->f_pmask[i] = 0;
       f->f_flags = 0;
     }
 
@@ -1839,6 +1865,7 @@ cfline (const char *line, struct filed *f)
 	  case '!':
 	    negate_pri = 1;
 	    break;
+	    
 	  case '=':
 	    excl_pri = 1;
 	    break;
@@ -1847,7 +1874,7 @@ cfline (const char *line, struct filed *f)
       /* Decode priority name and set up bit masks.  */
       if (*bp == '*')
 	{
-	  pri_clear = INTERNAL_NOPRI;
+	  pri_clear = 0;
 	  pri_set = LOG_UPTO (LOG_PRIMASK);
 	}
       else
@@ -1860,8 +1887,16 @@ cfline (const char *line, struct filed *f)
 	      logerror (ebuf);
 	      return;
 	    }
-	  pri_clear = 0;
-	  pri_set = excl_pri ? LOG_MASK (pri) : LOG_UPTO (pri);
+	  if (pri == INTERNAL_NOPRI)
+	    {
+	      pri_clear = 255;
+	      pri_set = 0;
+	    }
+	  else
+	    {
+	      pri_clear = 0;
+	      pri_set = excl_pri ? LOG_MASK (pri) : LOG_UPTO (pri);
+	    }
 	}
       if (negate_pri)
 	{
@@ -1884,6 +1919,7 @@ cfline (const char *line, struct filed *f)
 		 */
 		if (buf[1] == '*' && ((1 << i) & facilities_seen))
 		  continue;
+		
 		f->f_pmask[i] &= ~pri_clear;
 		f->f_pmask[i] |= pri_set;
 	      }
@@ -1899,6 +1935,7 @@ cfline (const char *line, struct filed *f)
 		  logerror (ebuf);
 		  return;
 		}
+
 	      f->f_pmask[LOG_FAC(i)] &= ~pri_clear;
 	      f->f_pmask[LOG_FAC(i)] |= pri_set;
 	    }
