@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -52,12 +48,13 @@ WINDOW	*line_win;
 
 int	curses_initialized = 0;
 
+#undef max
 /*
  * max HAS to be a function, it is called with
  * a argument of the form --foo at least once.
  */
-max(a,b)
-	int a, b;
+int
+max(int a, int b)
 {
 
 	return (a > b ? a : b);
@@ -67,10 +64,8 @@ max(a,b)
  * Display some text on somebody's window, processing some control
  * characters while we are at it.
  */
-display(win, text, size)
-	register xwin_t *win;
-	register char *text;
-	int size;
+int
+display(register xwin_t *win, register char *text, int size)
 {
 	register int i;
 	char cch;
@@ -81,6 +76,12 @@ display(win, text, size)
 			text++;
 			continue;
 		}
+		if (*text == '\a') {
+			beep();
+			wrefresh(curscr);
+			text++;
+			continue;
+		}
 		/* erase character */
 		if (*text == win->cerase) {
 			wmove(win->x_win, win->x_line, max(--win->x_col, 0));
@@ -157,8 +158,8 @@ display(win, text, size)
 /*
  * Read the character at the indicated position in win
  */
-readwin(win, line, col)
-	WINDOW *win;
+int
+readwin(WINDOW *win, int line, int col)
 {
 	int oldline, oldcol;
 	register int c;
@@ -174,9 +175,8 @@ readwin(win, line, col)
  * Scroll a window, blanking out the line following the current line
  * so that the current position is obvious
  */
-xscroll(win, flag)
-	register xwin_t *win;
-	int flag;
+int
+xscroll(register xwin_t *win, int flag)
 {
 
 	if (flag == -1) {
