@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -57,10 +53,11 @@ static char sccsid[] = "@(#)init_disp.c	8.2 (Berkeley) 2/16/94";
 #include <err.h>
 #include "talk.h"
 
-/* 
+/*
  * Set up curses, catch the appropriate signals,
  * and build the various windows.
  */
+int
 init_display()
 {
 	void sig_sent();
@@ -122,6 +119,7 @@ init_display()
  * the first three characters each talk transmits after
  * connection are the three edit characters.
  */
+int
 set_edit_chars()
 {
 	int cc;
@@ -158,7 +156,7 @@ set_edit_chars()
 #else /* !HAVE_TCGETATTR */
 	struct sgttyb tty;
 	struct ltchars ltc;
-	
+
 	ioctl(0, TIOCGETP, &tty);
 	ioctl(0, TIOCGLTC, (struct sgttyb *)&ltc);
 	my_win.cerase = tty.sg_erase;
@@ -194,6 +192,7 @@ sig_sent()
 /*
  * All done talking...hang up the phone and reset terminal thingy's
  */
+int
 quit()
 {
 
